@@ -15,44 +15,35 @@ import nfqueue
 sys.path.append('dpkt-1.6')
 from dpkt import ip
 
-def cb(i,payload):
-	print "python callback called !", i
+count = 0
+
+def cb(i, payload):
+	global count
+
+	print "python callback called !"
+	count += 1
 
-	print "payload len ", payload.get_length()
 	data = payload.get_data()
 	pkt = ip.IP(data)
-	print "proto:", pkt.p
-	print "source: %s" % inet_ntoa(pkt.src)
-	print "dest: %s" % inet_ntoa(pkt.dst)
 	if pkt.p == ip.IP_PROTO_TCP:
-	 	print "  sport: %s" % pkt.tcp.sport
-	 	print "  dport: %s" % pkt.tcp.dport
-        payload.set_verdict(nfqueue.NF_DROP)
+		print "  len %d proto %s src: %s:%s    dst %s:%s " % (payload.get_length(),pkt.p,inet_ntoa(pkt.src),pkt.tcp.sport,inet_ntoa(pkt.dst),pkt.tcp.dport)
+	else:
+		print "  len %d proto %s src: %s    dst %s " % (payload.get_length(),pkt.p,inet_ntoa(pkt.src),inet_ntoa(pkt.dst))
+
+	payload.set_verdict(nfqueue.NF_ACCEPT)
 
 	sys.stdout.flush()
 	return 1
 
 q = nfqueue.queue()
 
-print "open"
-q.open()
-
-print "bind"
-q.bind(AF_INET);
-
-#print "setting callback (should fail, wrong arg type)"
-#try:
-#	q.set_callback("blah")
-#except TypeError, e:
-#	print "type failure (expected), continuing"
-
 print "setting callback"
 q.set_callback(cb)
 
-print "creating queue"
-q.create_queue(0)
+print "open"
+q.fast_open(0, AF_INET)
 
-q.set_queue_maxlen(5000)
+q.set_queue_maxlen(50000)
 
 print "trying to run"
 try:
@@ -60,6 +51,7 @@ try:
 except KeyboardInterrupt, e:
 	print "interrupted"
 
+print "%d packets handled" % count
 
 print "unbind"
 q.unbind(AF_INET)
