@@ -1,7 +1,6 @@
 #ifndef __NFQ_COMMON__
 #define __NFQ_COMMON__
 
-extern void raise_swig_error(const char *errstr);
 extern int  swig_nfq_callback(struct nfq_q_handle *qh, struct nfgenmsg *nfmsg,
                        struct nfq_data *nfad, void *data);
 
@@ -21,6 +20,12 @@ int queue_create_queue(struct queue *self, int queue_num);
 
 int queue_fast_open(struct queue *self, int queue_num, int af_family);
 
+int queue_get_fd(struct queue *self);
+
+int queue_set_mode(struct queue *self, int mode);
+
+int queue_process_pending(struct queue *self, int max_count);
+
 int queue_try_run(struct queue *self);
 
 int payload_get_nfmark(struct payload *self);
